==> hibernate-core-5.3.18.Final-sources.jar: org/hibernate/jpa/internal/JpaComplianceImpl.java <==
/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * License: GNU Lesser General Public License (LGPL), version 2.1 or later.
 * See the lgpl.txt file in the root directory or <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
package org.hibernate.jpa.internal;

import org.hibernate.jpa.spi.JpaCompliance;

/**
 * @author Andrea Boriero
 */
public class JpaComplianceImpl implements JpaCompliance {
	private boolean queryCompliance;
	private boolean transactionCompliance;
	private boolean listCompliance;
	private boolean closedCompliance;
	private boolean proxyCompliance;
	private boolean cachingCompliance;
	private boolean globalGeneratorNameScopeCompliance;

	private JpaComplianceImpl(
			boolean queryCompliance,
			boolean transactionCompliance,
			boolean listCompliance,
			boolean closedCompliance,
			boolean proxyCompliance,
			boolean cachingCompliance,
			boolean globalGeneratorNameScopeCompliance) {
		this.queryCompliance = queryCompliance;
		this.transactionCompliance = transactionCompliance;
		this.listCompliance = listCompliance;
		this.closedCompliance = closedCompliance;
		this.proxyCompliance = proxyCompliance;
		this.cachingCompliance = cachingCompliance;
		this.globalGeneratorNameScopeCompliance = globalGeneratorNameScopeCompliance;
	}

	@Override
	public boolean isJpaQueryComplianceEnabled() {
		return queryCompliance;
	}

	@Override
	public boolean isJpaTransactionComplianceEnabled() {
		return transactionCompliance;
	}

	@Override
	public boolean isJpaListComplianceEnabled() {
		return listCompliance;
	}

	@Override
	public boolean isJpaClosedComplianceEnabled() {
		return closedCompliance;
	}

	@Override
	public boolean isJpaProxyComplianceEnabled() {
		return proxyCompliance;
	}

	@Override
	public boolean isJpaCacheComplianceEnabled() {
		return cachingCompliance;
	}

	@Override
	public boolean isGlobalGeneratorScopeEnabled() {
		return globalGeneratorNameScopeCompliance;
	}

	public static class JpaComplianceBuilder {
		private boolean queryCompliance;
		private boolean transactionCompliance;
		private boolean listCompliance;
		private boolean closedCompliance;
		private boolean proxyCompliance;
		private boolean cachingCompliance;
		private boolean globalGeneratorNameScopeCompliance;

		public JpaComplianceBuilder() {
		}

		public JpaComplianceBuilder setQueryCompliance(boolean queryCompliance) {
			this.queryCompliance = queryCompliance;
			return this;
		}

		public JpaComplianceBuilder setTransactionCompliance(boolean transactionCompliance) {
			this.transactionCompliance = transactionCompliance;
			return this;
		}

		public JpaComplianceBuilder setListCompliance(boolean listCompliance) {
			this.listCompliance = listCompliance;
			return this;
		}

		public JpaComplianceBuilder setClosedCompliance(boolean closedCompliance) {
			this.closedCompliance = closedCompliance;
			return this;
		}

		public JpaComplianceBuilder setProxyCompliance(boolean proxyCompliance) {
			this.proxyCompliance = proxyCompliance;
			return this;
		}

		public JpaComplianceBuilder setCachingCompliance(boolean cachingCompliance) {
			this.cachingCompliance = cachingCompliance;
			return this;
		}

		public JpaComplianceBuilder setGlobalGeneratorNameCompliance(boolean globalGeneratorNameCompliance) {
			this.globalGeneratorNameScopeCompliance = globalGeneratorNameCompliance;
			return this;
		}

		JpaCompliance createJpaCompliance() {
			return new JpaComplianceImpl(
					queryCompliance,
					transactionCompliance,
					listCompliance,
					closedCompliance,
					proxyCompliance,
					cachingCompliance,
					globalGeneratorNameScopeCompliance
			);
		}
	}
}

==> hibernate-core-6.2.2.Final-sources.jar: org/hibernate/jpa/internal/JpaComplianceImpl.java <==
/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * License: GNU Lesser General Public License (LGPL), version 2.1 or later.
 * See the lgpl.txt file in the root directory or <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
package org.hibernate.jpa.internal;

import org.hibernate.jpa.spi.JpaCompliance;

/**
 * @author Andrea Boriero
 */
public class JpaComplianceImpl implements JpaCompliance {
	private final boolean listCompliance;
	private final boolean orderByMappingCompliance;
	private final boolean proxyCompliance;
	private final boolean globalGeneratorNameScopeCompliance;
	private final boolean queryCompliance;
	private final boolean transactionCompliance;
	private final boolean closedCompliance;
	private final boolean cachingCompliance;
	private final boolean loadByIdCompliance;

	public JpaComplianceImpl(
			boolean listCompliance,
			boolean orderByMappingCompliance,
			boolean proxyCompliance,
			boolean globalGeneratorNameScopeCompliance,
			boolean queryCompliance,
			boolean transactionCompliance,
			boolean closedCompliance,
			boolean cachingCompliance,
			boolean loadByIdCompliance) {
		this.queryCompliance = queryCompliance;
		this.transactionCompliance = transactionCompliance;
		this.listCompliance = listCompliance;
		this.closedCompliance = closedCompliance;
		this.proxyCompliance = proxyCompliance;
		this.cachingCompliance = cachingCompliance;
		this.globalGeneratorNameScopeCompliance = globalGeneratorNameScopeCompliance;
		this.orderByMappingCompliance = orderByMappingCompliance;
		this.loadByIdCompliance = loadByIdCompliance;
	}

	@Override
	public boolean isJpaQueryComplianceEnabled() {
		return queryCompliance;
	}

	@Override
	public boolean isJpaTransactionComplianceEnabled() {
		return transactionCompliance;
	}

	@Override
	public boolean isJpaListComplianceEnabled() {
		return listCompliance;
	}

	@Override
	public boolean isJpaClosedComplianceEnabled() {
		return closedCompliance;
	}

	@Override
	public boolean isJpaProxyComplianceEnabled() {
		return proxyCompliance;
	}

	@Override
	public boolean isJpaCacheComplianceEnabled() {
		return cachingCompliance;
	}

	@Override
	public boolean isGlobalGeneratorScopeEnabled() {
		return globalGeneratorNameScopeCompliance;
	}

	@Override
	public boolean isJpaOrderByMappingComplianceEnabled() {
		return orderByMappingCompliance;
	}

	@Override
	public boolean isLoadByIdComplianceEnabled() {
		return loadByIdCompliance;
	}

	public static class JpaComplianceBuilder {
		private boolean queryCompliance;
		private boolean listCompliance;
		private boolean orderByMappingCompliance;
		private boolean proxyCompliance;
		private boolean globalGeneratorNameScopeCompliance;
		private boolean cachingCompliance;
		private boolean transactionCompliance;
		private boolean closedCompliance;
		private boolean loadByIdCompliance;

		public JpaComplianceBuilder() {
		}

		public JpaComplianceBuilder setListCompliance(boolean listCompliance) {
			this.listCompliance = listCompliance;
			return this;
		}

		public JpaComplianceBuilder setOrderByMappingCompliance(boolean orderByMappingCompliance) {
			this.orderByMappingCompliance = orderByMappingCompliance;
			return this;
		}

		public JpaComplianceBuilder setProxyCompliance(boolean proxyCompliance) {
			this.proxyCompliance = proxyCompliance;
			return this;
		}

		public JpaComplianceBuilder setQueryCompliance(boolean queryCompliance) {
			this.queryCompliance = queryCompliance;
			return this;
		}

		public JpaComplianceBuilder setTransactionCompliance(boolean transactionCompliance) {
			this.transactionCompliance = transactionCompliance;
			return this;
		}

		public JpaComplianceBuilder setClosedCompliance(boolean closedCompliance) {
			this.closedCompliance = closedCompliance;
			return this;
		}

		public JpaComplianceBuilder setCachingCompliance(boolean cachingCompliance) {
			this.cachingCompliance = cachingCompliance;
			return this;
		}

		public JpaComplianceBuilder setGlobalGeneratorNameCompliance(boolean globalGeneratorNameCompliance) {
			this.globalGeneratorNameScopeCompliance = globalGeneratorNameCompliance;
			return this;
		}

		public JpaComplianceBuilder setLoadByIdCompliance(boolean loadByIdCompliance) {
			this.loadByIdCompliance = loadByIdCompliance;
			return this;
		}

		JpaCompliance createJpaCompliance() {
			return new JpaComplianceImpl(
					listCompliance,
					orderByMappingCompliance,
					proxyCompliance,
					globalGeneratorNameScopeCompliance,
					queryCompliance,
					transactionCompliance,
					closedCompliance,
					cachingCompliance,
					loadByIdCompliance
			);
		}
	}
}
